==> blesta-5.10.2.zip: blesta/language/ru_ru/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Группа редактирования';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Использование адресов электронной почты в качестве имен пользователей';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Использовать настройки компании (снимите флажок, чтобы указать ниже)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Способы доставки счетов-фактур';
$lang['AdminCompanyGroups.edit.field_description'] = 'Описание';
$lang['AdminCompanyGroups.edit.field_color'] = 'Цвет';
$lang['AdminCompanyGroups.edit.field_name'] = 'Имя';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Обязательные поля клиента';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Общие настройки клиента';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Уведомления';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Доставка счетов-фактур';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Плата за опоздание';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Варианты выставления счетов и начислений';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Основные опции';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Группа редактирования';
$lang['AdminCompanyGroups.edit.page_title'] = 'Настройки > Компания > Группы клиентов > Редактировать группу';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Создать группу';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Включить проверку электронной почты';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Использование адресов электронной почты в качестве имен пользователей';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Использовать настройки компании (снимите флажок, чтобы указать ниже)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Способы доставки счетов-фактур';
$lang['AdminCompanyGroups.add.field_description'] = 'Описание';
$lang['AdminCompanyGroups.add.field_color'] = 'Цвет';
$lang['AdminCompanyGroups.add.field_name'] = 'Имя';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Обязательные поля клиента';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Общие настройки клиента';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Уведомления';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Доставка счетов-фактур';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Плата за опоздание';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Варианты выставления счетов и начислений';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Основные опции';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Создать группу';
$lang['AdminCompanyGroups.add.page_title'] = 'Настройки > Компания > Группы клиентов > Создать группу';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Вы уверены, что хотите удалить эту группу клиентов? Все клиенты в этой группе будут перемещены в группу по умолчанию.';
$lang['AdminCompanyGroups.index.no_results'] = 'Клиентских групп не существует.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Удалить';
$lang['AdminCompanyGroups.index.option_edit'] = 'Редактировать';
$lang['AdminCompanyGroups.index.text_options'] = 'Опции';
$lang['AdminCompanyGroups.index.text_clients'] = 'Количество клиентов';
$lang['AdminCompanyGroups.index.text_description'] = 'Описание';
$lang['AdminCompanyGroups.index.text_name'] = 'Имя';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Создать группу';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Группы клиентов';
$lang['AdminCompanyGroups.index.page_title'] = 'Настройки > Компания > Группы клиентов';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Установите флажок, чтобы отправлять письмо с подтверждением электронной почты, когда создается новый логин или клиент меняет свой e-mail. Уведомление будет появляться в профиле клиента до тех пор, пока он не пройдет верификацию.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Удаляет возможность для клиентов определять свое собственное имя пользователя.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s является группой по умолчанию и не может быть удалена.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s был успешно удален!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s был успешно отредактирован!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s был успешно создан!';

==> blesta-5.11.4.zip: blesta/language/ru_ru/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Группа редактирования';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Использование адресов электронной почты в качестве имен пользователей';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Использовать настройки компании (снимите флажок, чтобы указать ниже)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Способы доставки счетов-фактур';
$lang['AdminCompanyGroups.edit.field_description'] = 'Описание';
$lang['AdminCompanyGroups.edit.field_color'] = 'Цвет';
$lang['AdminCompanyGroups.edit.field_name'] = 'Имя';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Обязательные поля клиента';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Общие настройки клиента';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Уведомления';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Доставка счетов-фактур';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Плата за опоздание';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Варианты выставления счетов и начислений';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Основные опции';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Группа редактирования';
$lang['AdminCompanyGroups.edit.page_title'] = 'Настройки > Компания > Группы клиентов > Редактировать группу';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Создать группу';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Включить проверку электронной почты';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Использование адресов электронной почты в качестве имен пользователей';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Использовать настройки компании (снимите флажок, чтобы указать ниже)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Способы доставки счетов-фактур';
$lang['AdminCompanyGroups.add.field_description'] = 'Описание';
$lang['AdminCompanyGroups.add.field_color'] = 'Цвет';
$lang['AdminCompanyGroups.add.field_name'] = 'Имя';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Обязательные поля клиента';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Общие настройки клиента';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Уведомления';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Доставка счетов-фактур';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Плата за опоздание';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Варианты выставления счетов и начислений';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Основные опции';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Создать группу';
$lang['AdminCompanyGroups.add.page_title'] = 'Настройки > Компания > Группы клиентов > Создать группу';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Вы уверены, что хотите удалить эту группу клиентов? Все клиенты в этой группе будут перемещены в группу по умолчанию.';
$lang['AdminCompanyGroups.index.no_results'] = 'Клиентских групп не существует.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Удалить';
$lang['AdminCompanyGroups.index.option_edit'] = 'Редактировать';
$lang['AdminCompanyGroups.index.text_options'] = 'Опции';
$lang['AdminCompanyGroups.index.text_clients'] = 'Количество клиентов';
$lang['AdminCompanyGroups.index.text_description'] = 'Описание';
$lang['AdminCompanyGroups.index.text_name'] = 'Имя';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Создать группу';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Группы клиентов';
$lang['AdminCompanyGroups.index.page_title'] = 'Настройки > Компания > Группы клиентов';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Установите флажок, чтобы отправлять письмо с подтверждением электронной почты, когда создается новый логин или клиент меняет свой e-mail. Уведомление будет появляться в профиле клиента до тех пор, пока он не пройдет верификацию.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Удаляет возможность для клиентов определять свое собственное имя пользователя.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s является группой по умолчанию и не может быть удалена.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s был успешно удален!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s был успешно отредактирован!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s был успешно создан!';
$lang['AdminCompanyGroups.edit.heading_gateway_restrictions'] = 'Разрешенные шлюзы';
$lang['AdminCompanyGroups.add.heading_gateway_restrictions'] = 'Разрешенные шлюзы';
